Installation
============
There are several ways to download and install BioKEEN.

.. warning:: BioKEEN requires Python 3.6+

Easiest
~~~~~~~
Download the latest stable code from `PyPI <https://pypi.python.org/pypi/biokeen>`_ with:

.. code-block:: sh

   $ pip install biokeen

Get the Latest
~~~~~~~~~~~~~~~
Download the most recent code from `GitHub <https://github.com/SmartDataAnalytics/BioKEEN>`_ with:

.. code-block:: sh

   $ pip install git+https://github.com/SmartDataAnalytics/BioKEEN.git
